@@ -86,7 +86,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56500
 #  endif
 #endif
 
@@ -115,6 +115,36 @@
 #else
 #  define KCALENDARCORE_DEPRECATED_VERSION_5_64(text)
 #endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55900
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_89(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_89(text)
+#endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_91(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_91(text)
+#endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55f00
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_95(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_95(text)
+#endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56000
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_96(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_96(text)
+#endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KCALENDARCORE_DEPRECATED_VERSION_5(minor, text)      KCALENDARCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCALENDARCORE_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -180,7 +210,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +220,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56500
 #  endif
 #endif
 
@@ -209,6 +239,36 @@
 #else
 #  define KCALENDARCORE_DEPRECATED_VERSION_5_64(text)
 #endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55900
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_89(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_89(text)
+#endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_91(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_91(text)
+#endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55f00
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_95(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_95(text)
+#endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56000
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_96(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_96(text)
+#endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KCALENDARCORE_DEPRECATED_VERSION_5(minor, text)      KCALENDARCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCALENDARCORE_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
